==> qore-0.8.13.4.tar.bz2: qore-0.8.13.4/docs/library/html/index.js <==
var index =
[
    [ "Introduction to the Qore Library", "index.html#introduction", null ],
    [ "Embedding Qore Code", "embedding.html", [
      [ "Embedding Qore Code", "embedding.html#embedding", [
        [ "Initializing and Closing the Qore Library", "embedding.html#initializing_and_closing_library", null ],
        [ "Parsing and Running Qore Code", "embedding.html#parsing_and_running", null ]
      ] ]
    ] ],
    [ "Qore Data", "qore_data.html", [
      [ "Qore Data", "qore_data.html#handling_data", [
        [ "Simple Value Types: QoreBigIntNode, QoreFloatNode, QoreStringNode, DateTimeNode, BinaryNode", "qore_data.html#simple_value_types", null ],
        [ "Unique Value Types: QoreBoolNode, QoreNullNode, QoreNothingNode", "qore_data.html#unique_value_types", null ],
        [ "Container Value Types: QoreHashNode, QoreListNode, QoreObject", "qore_data.html#container_types", null ],
        [ "Object Value Type: QoreObject", "qore_data.html#qoreobject", null ],
        [ "Handling Reference Arguments: ReferenceNode and ReferenceHelper", "qore_data.html#reference_arguments", null ]
      ] ]
    ] ],
    [ "Qore Builtin Functions", "builtin_functions.html", [
      [ "Qore Builtin Functions", "builtin_functions.html#builtin_functions", [
        [ "Handling Function Arguments", "builtin_functions.html#handling_function_arguments", null ],
        [ "Function Return Value", "builtin_functions.html#function_return_value", null ],
        [ "Raising Exceptions in a Function", "builtin_functions.html#function_raising_exceptions", null ]
      ] ]
    ] ],
    [ "Implementing Qore Classes", "class_implementation.html", [
      [ "Implementing Qore Classes", "class_implementation.html#class_implementation", [
        [ "Constructor Methods", "class_implementation.html#constructor_methods", null ],
        [ "Copy Methods", "class_implementation.html#copy_methods", null ],
        [ "Destructor Methods", "class_implementation.html#destructor_methods", null ],
        [ "Regular Class Methods", "class_implementation.html#regular_class_methods", null ],
        [ "Static Class Methods", "class_implementation.html#static_class_methods", null ],
        [ "Threading Issues in Class Implementation", "class_implementation.html#object_threading_issues", null ],
        [ "Implementing Class Hierarchies", "class_implementation.html#class_hierarchies", null ]
      ] ]
    ] ],
    [ "Developing Qore Modules", "qore_modules.html", [
      [ "Qore Module development", "qore_modules.html#module_dev", [
        [ "Module Header Info", "qore_modules.html#module_header", null ],
        [ "Module Functions", "qore_modules.html#module_functions", null ]
      ] ]
    ] ],
    [ "Implementing Qore DBI Drivers", "dbi_drivers.html", [
      [ "Implementing Qore DBI Drivers", "dbi_drivers.html#dbi_drivers", [
        [ "DBI Function Overview", "dbi_drivers.html#dbi_function_overview", null ],
        [ "DBI Open Method", "dbi_drivers.html#dbi_open", null ],
        [ "DBI Close Method", "dbi_drivers.html#dbi_close", null ],
        [ "DBI Select Method", "dbi_drivers.html#dbi_select", null ],
        [ "DBI SelectRows Method", "dbi_drivers.html#dbi_select_rows", null ],
        [ "DBI Exec Method", "dbi_drivers.html#dbi_exec", null ],
        [ "DBI Commit Method", "dbi_drivers.html#dbi_commit", null ],
        [ "DBI Rollback Method", "dbi_drivers.html#dbi_rollback", null ],
        [ "DBI BeginTransaction Method", "dbi_drivers.html#dbi_begin_transaction", null ],
        [ "DBI AbortTransactionStart Method", "dbi_drivers.html#dbi_abort_transaction_start", null ],
        [ "DBI GetServerVersion Method", "dbi_drivers.html#dbi_get_server_version", null ],
        [ "DBI GetClientVersion Method", "dbi_drivers.html#dbi_get_client_version", null ]
      ] ]
    ] ],
    [ "Using Qore with CMake Build System", "qore_cmake.html", [
      [ "Using Qore and CMake", "qore_cmake.html#qore_cmake_about", null ],
      [ "Build Type Handling", "qore_cmake.html#qore_cmake_build_type", null ],
      [ "FIND_PACKAGE Arguments", "qore_cmake.html#qore_cmake_find_package", [
        [ "CMake Qore Variables", "qore_cmake.html#qore_cmake_variables", null ],
        [ "Compiler Defines", "qore_cmake.html#qore_cmake_defines", null ]
      ] ],
      [ "Qore Binary Modules Support for CMake", "qore_cmake.html#qore_cmake_binary_modules", [
        [ "QORE_WRAP_QPP", "qore_cmake.html#QORE_WRAP_QPP", null ],
        [ "QORE_BINARY_MODULE", "qore_cmake.html#QORE_BINARY_MODULE", null ],
        [ "QORE_DIST", "qore_cmake.html#QORE_DIST", null ],
        [ "QORE_CONFIG_INFO", "qore_cmake.html#QORE_CONFIG_INFO", null ],
        [ "Qore Binary Module Example", "qore_cmake.html#qore_cmake_binary_modules_example", null ]
      ] ]
    ] ]
];

==> qore-0.8.13.5.tar.bz2: qore-0.8.13.5/docs/library/html/index.js <==
var index =
[
    [ "Introduction to the Qore Library", "index.html#introduction", null ],
    [ "Embedding Qore Code", "embedding.html", null ],
    [ "Qore Data", "qore_data.html", [
      [ "Qore Data", "qore_data.html#handling_data", [
        [ "Initializing and Closing the Qore Library", "embedding.html#initializing_and_closing_library", null ],
        [ "Parsing and Running Qore Code", "embedding.html#parsing_and_running", null ],
        [ "Simple Value Types: QoreBigIntNode, QoreFloatNode, QoreStringNode, DateTimeNode, BinaryNode", "qore_data.html#simple_value_types", null ],
        [ "Unique Value Types: QoreBoolNode, QoreNullNode, QoreNothingNode", "qore_data.html#unique_value_types", null ],
        [ "Container Value Types: QoreHashNode, QoreListNode, QoreObject", "qore_data.html#container_types", null ],
        [ "Object Value Type: QoreObject", "qore_data.html#qoreobject", null ],
        [ "Handling Reference Arguments: ReferenceNode and ReferenceHelper", "qore_data.html#reference_arguments", null ]
      ] ]
    ] ],
    [ "Qore Builtin Functions", "builtin_functions.html", null ],
    [ "Implementing Qore Classes", "class_implementation.html", null ],
    [ "Developing Qore Modules", "qore_modules.html", [
      [ "Qore Module development", "qore_modules.html#module_dev", [
        [ "Handling Function Arguments", "builtin_functions.html#handling_function_arguments", null ],
        [ "Function Return Value", "builtin_functions.html#function_return_value", null ],
        [ "Raising Exceptions in a Function", "builtin_functions.html#function_raising_exceptions", null ],
        [ "Constructor Methods", "class_implementation.html#constructor_methods", null ],
        [ "Copy Methods", "class_implementation.html#copy_methods", null ],
        [ "Destructor Methods", "class_implementation.html#destructor_methods", null ],
        [ "Regular Class Methods", "class_implementation.html#regular_class_methods", null ],
        [ "Static Class Methods", "class_implementation.html#static_class_methods", null ],
        [ "Threading Issues in Class Implementation", "class_implementation.html#object_threading_issues", null ],
        [ "Implementing Class Hierarchies", "class_implementation.html#class_hierarchies", null ],
        [ "Module Header Info", "qore_modules.html#module_header", null ],
        [ "Module Functions", "qore_modules.html#module_functions", null ]
      ] ]
    ] ],
    [ "Implementing Qore DBI Drivers", "dbi_drivers.html", null ],
    [ "Using Qore with CMake Build System", "qore_cmake.html", [
      [ "Using Qore and CMake", "qore_cmake.html#qore_cmake_about", null ],
      [ "Build Type Handling", "qore_cmake.html#qore_cmake_build_type", null ],
      [ "FIND_PACKAGE Arguments", "qore_cmake.html#qore_cmake_find_package", [
        [ "DBI Function Overview", "dbi_drivers.html#dbi_function_overview", null ],
        [ "DBI Open Method", "dbi_drivers.html#dbi_open", null ],
        [ "DBI Close Method", "dbi_drivers.html#dbi_close", null ],
        [ "DBI Select Method", "dbi_drivers.html#dbi_select", null ],
        [ "DBI SelectRows Method", "dbi_drivers.html#dbi_select_rows", null ],
        [ "DBI Exec Method", "dbi_drivers.html#dbi_exec", null ],
        [ "DBI Commit Method", "dbi_drivers.html#dbi_commit", null ],
        [ "DBI Rollback Method", "dbi_drivers.html#dbi_rollback", null ],
        [ "DBI BeginTransaction Method", "dbi_drivers.html#dbi_begin_transaction", null ],
        [ "DBI AbortTransactionStart Method", "dbi_drivers.html#dbi_abort_transaction_start", null ],
        [ "DBI GetServerVersion Method", "dbi_drivers.html#dbi_get_server_version", null ],
        [ "DBI GetClientVersion Method", "dbi_drivers.html#dbi_get_client_version", null ],
        [ "CMake Qore Variables", "qore_cmake.html#qore_cmake_variables", null ],
        [ "Compiler Defines", "qore_cmake.html#qore_cmake_defines", null ]
      ] ],
      [ "Qore Binary Modules Support for CMake", "qore_cmake.html#qore_cmake_binary_modules", [
        [ "QORE_WRAP_QPP", "qore_cmake.html#QORE_WRAP_QPP", null ],
        [ "QORE_BINARY_MODULE", "qore_cmake.html#QORE_BINARY_MODULE", null ],
        [ "QORE_DIST", "qore_cmake.html#QORE_DIST", null ],
        [ "QORE_CONFIG_INFO", "qore_cmake.html#QORE_CONFIG_INFO", null ],
        [ "Qore Binary Module Example", "qore_cmake.html#qore_cmake_binary_modules_example", null ]
      ] ]
    ] ]
];
